# 规则引擎（Rule Engine）

## 简介

规则引擎是一个针对时序数据流根据规则执行自动诊断并触发相应操作的组件。

具体使用请参考[刻行文档](https://docs.coscene.cn/docs/recipes/data-diagnosis/rule-engine)

## 依赖

```shell
make install
```

## 测试

```shell
make test
```